Welcome to chop’s documentation! — chop documentation

# Welcome to chop’s documentation!

`optim` | Full-gradient optimizers.
`stochastic` | Stochastic optimizers.
`constraints` | Constraints.
`adversary` | Adversary utility classes.
`penalties` | Penalties.
`utils` | General utility functions.
`data` | Data loading utilities.
`image` | Image utilities.
`logging` | Logging utilities.

## Where to go from here?

To know more about chop, check out our example gallery or browse through the module reference using the left navigation bar.

Last change: Jan 08, 2021

# Indices and tables

- Index

- Module Index

- Search Page